@@ -174,29 +174,37 @@ class Horde_Crypt_Smime extends Horde_Crypt
      * Extract the contents from signed S/MIME data.
      *
      * @param string $data     The signed S/MIME data.
-     * @param string $sslpath  The path to the OpenSSL binary.
+     * @param string $sslpath  The path to the OpenSSL binary. @deprecated and
+     *                         not used, just for backwards-compatibility.
      *
      * @return string  The contents embedded in the signed data.
      * @throws Horde_Crypt_Exception
      */
-    public function extractSignedContents($data, $sslpath)
+    public function extractSignedContents($data, $sslpath = null)
     {
         /* Check for availability of OpenSSL PHP extension. */
         $this->checkForOpenSSL();
 
-        /* Create temp files for input/output. */
+        /* Create temp files for input/output/certs. */
         $input = $this->_createTempFile('horde-smime');
         $output = $this->_createTempFile('horde-smime');
+        $certs = $this->_createTempFile('horde-smime');
 
         /* Write text to file. */
         file_put_contents($input, $data);
         unset($data);
 
-        exec($sslpath . ' smime -verify -noverify -nochain -in ' . $input . ' -out ' . $output);
-
-        $ret = file_get_contents($output);
-        if ($ret) {
-            return $ret;
+        /* Unfortunatelly the openssl_pkcs7_verify method does not behave as
+         * explained in openssl extensions documentation, it does not return
+         * content if no certs specified. Therefore, we need to use double
+         * verification which the first one tries to extract certificats then
+         * the second to extract content. */
+        if (openssl_pkcs7_verify($input, PKCS7_NOVERIFY, $certs) === true &&
+            openssl_pkcs7_verify($input, PKCS7_NOVERIFY, $certs, array(), $certs, $output) === true) {
+            $ret = file_get_contents($output);
+            if ($ret) {
+                return $ret;
+            }
         }
 
         throw new Horde_Crypt_Exception(Horde_Crypt_Translation::t("OpenSSL error: Could not extract data from signed S/MIME part."));
